@@ -6,17 +6,17 @@ my $p= __PACKAGE__;
 
 $p->attr('m1')
   ->class_attr('m2')
-  ->hybrid_attr('m3')
+  ->dual_attr('m3')
 
   ->attr([qw/m4_1 m4_2/])
   ->class_attr([qw/m5_1 m5_2/])
-  ->hybrid_attr([qw/m6_1 m6_2/])
+  ->dual_attr([qw/m6_1 m6_2/])
 
   ->attr(m7 => (build => 7))
   ->attr([qw/m8_1 m8_2/] => (default => sub { 8 }))
 
   ->class_attr(m9 => (default => 9))
-  ->hybrid_attr(m10 => (default => 10))
+  ->dual_attr(m10 => (default => 10))
 
   ->attr(m11 => (type => 'array', deref => 1))
   ->attr(m12 => (type => 'hash', deref => 1))
@@ -24,10 +24,10 @@ $p->attr('m1')
   ->class_attr(m13 => (type => 'array', deref => 1))
   ->class_attr(m14 => (type => 'hash', deref => 1))
 
-  ->hybrid_attr(m15 => (type => 'array', deref => 1))
-  ->hybrid_attr(m16 => (type => 'hash', deref => 1))
+  ->dual_attr(m15 => (type => 'array', deref => 1))
+  ->dual_attr(m16 => (type => 'hash', deref => 1))
 
-  ->hybrid_attr(m17 =>
+  ->dual_attr(m17 =>
       type => 'hash', default => sub {{a => 1}}, clone => 'hash')
 ;
 
